@@ -4,10 +4,11 @@ import (
 	"errors"
 	"fmt"
 	"path/filepath"
+	"slices"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Python struct {
@@ -20,18 +21,20 @@ const (
 	// FetchVirtualEnv fetches the virtual env
 	FetchVirtualEnv      properties.Property = "fetch_virtual_env"
 	UsePythonVersionFile properties.Property = "use_python_version_file"
+	FolderNameFallback   properties.Property = "folder_name_fallback"
+	DefaultVenvNames     properties.Property = "default_venv_names"
 )
 
 func (p *Python) Template() string {
 	return " {{ if .Error }}{{ .Error }}{{ else }}{{ if .Venv }}{{ .Venv }} {{ end }}{{ .Full }}{{ end }} "
 }
 
-func (p *Python) Init(props properties.Properties, env platform.Environment) {
+func (p *Python) Init(props properties.Properties, env runtime.Environment) {
 	p.language = language{
 		env:         env,
 		props:       props,
 		extensions:  []string{"*.py", "*.ipynb", "pyproject.toml", "venv.bak"},
-		folders:     []string{".venv", "venv", "virtualenv", "env", "venv-win", "pyenv-win"},
+		folders:     []string{".venv", "venv", "virtualenv", "venv-win", "pyenv-win"},
 		loadContext: p.loadContext,
 		inContext:   p.inContext,
 		commands: []*cmd{
@@ -49,6 +52,11 @@ func (p *Python) Init(props properties.Properties, env platform.Environment) {
 				args:       []string{"--version"},
 				regex:      `(?:Python (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+))))`,
 			},
+			{
+				executable: "py",
+				args:       []string{"--version"},
+				regex:      `(?:Python (?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+))))`,
+			},
 		},
 		versionURLTemplate: "https://docs.python.org/release/{{ .Major }}.{{ .Minor }}.{{ .Patch }}/whatsnew/changelog.html#python-{{ .Major }}-{{ .Minor }}-{{ .Patch }}",
 		displayMode:        props.GetString(DisplayMode, DisplayModeEnvironment),
@@ -72,13 +80,26 @@ func (p *Python) loadContext() {
 		"CONDA_ENV_PATH",
 		"CONDA_DEFAULT_ENV",
 	}
+
+	folderNameFallback := p.language.props.GetBool(FolderNameFallback, true)
+	defaultVenvNames := p.language.props.GetStringArray(DefaultVenvNames, []string{
+		".venv",
+		"venv",
+	})
+
 	var venv string
 	for _, venvVar := range venvVars {
 		venv = p.language.env.Getenv(venvVar)
 		if len(venv) == 0 {
 			continue
 		}
-		name := platform.Base(p.language.env, venv)
+
+		name := runtime.Base(p.language.env, venv)
+		if folderNameFallback && slices.Contains(defaultVenvNames, name) {
+			venv = strings.TrimSuffix(venv, name)
+			name = runtime.Base(p.language.env, venv)
+		}
+
 		if p.canUseVenvName(name) {
 			p.Venv = name
 			break
